@@ -269,15 +269,10 @@ class ParameterSweep(object):
 
     def adjust_vQ(self, ROXIE_File):
         if max(self.ParametersLEDET.Inputs.nStrands_inGroup) > 1:
-            if np.all(self.ParametersLEDET.Inputs.nStrands_inGroup == self.ParametersLEDET.Inputs.nStrands_inGroup[0]):
-                B = self.acquireBField(ROXIE_File)
-                B = B[::int(self.ParametersLEDET.Inputs.nStrands_inGroup[0])]
-            else:
-                print('vQ calculation only supports equally-stranded wires so far!. Abort.')
-                return
-        else:
-            B = self.acquireBField(ROXIE_File)
+            print('vQ calculation only supports single-stranded wires so far!. Abort.')
+            return
         I = self.ParametersLEDET.Inputs.I00
+        B = self.acquireBField(ROXIE_File)
         T_bath = self.ParametersLEDET.Inputs.T00
         cable = Cable()
         cable.A_CableInsulated = (self.ParametersLEDET.Inputs.wBare_inGroup+2*self.ParametersLEDET.Inputs.wIns_inGroup) \
@@ -301,7 +296,7 @@ class ParameterSweep(object):
         vQ = 2*self.quenchPropagationVelocity(I, B, T_bath, cable)*1.21
         self.ParametersLEDET.setAttribute(getattr(self.ParametersLEDET, "Inputs"), "vQ_iStartQuench", vQ)
 
-    def prepareSimulation(self, MagnetName, folder, cleanFolder = True,  OffsetNumber = 0, ROXIE_File = '', clean = False):
+    def prepareSimulation(self, MagnetName, folder, cleanFolder = True,  OffsetNumber = 0, ROXIE_File = ''):
         Adjust_vQ = 0
         if ROXIE_File:
             Adjust_vQ =1
@@ -315,8 +310,7 @@ class ParameterSweep(object):
             for f in filelist:
                 if "selfMutualInductanceMatrix" in f:
                     continue
-                if clean:
-                    os.remove(os.path.join(folder, f))
+                os.remove(os.path.join(folder, f))
         #2. Generate Permutations
         self.generatePermutations()
         #3. For loop for all Simulations
@@ -424,11 +418,10 @@ class MinMaxSweep(ParameterSweep):
         print('Warning: Current Sweep only works for FPA \n')
         if len(current_vector) == 0:
             if basePoints <= 2:
-                print('Less than 3 current level provided. Set first current as level.')
-                current_vector = np.array([ultimateCurrent])
-            else:
-                nomCurrent = self.ParametersLEDET.Options.Iref
-                current_vector = np.linspace(10, ultimateCurrent, basePoints-1)
-                current_vector = np.append(current_vector, nomCurrent)
+                print('Current Sweep needs at least 3 points. Abort.')
+                return
+            nomCurrent = self.ParametersLEDET.Options.Iref
+            current_vector = np.linspace(10, ultimateCurrent, basePoints-1)
+            current_vector = np.append(current_vector, nomCurrent)
         self.addParameterToSweep_Vector('I00', current_vector)
 
