@@ -175,17 +175,18 @@ def EvaluateSimulations(MatFolder, MagnetName, MeasFile, SweepObject, Mat = True
 
     #Parameter Importance Study -- Ablation Analysis
     # 1. Extract best 10% of the Simulations
-    NumberBest = int(np.floor(SimData.shape[0]/10))
+    NumberBest = int(np.floor(SimData.shape[0]/1))
     if SimData.shape[0]<10: NumberBest = SimData.shape[0]-3
     BestFit = np.argsort(MSESims[:, 1])[0:NumberBest]
     SweepedParameters = SweepMatrix.shape[1]
     AbMatrix = np.zeros((SweepedParameters, NumberBest))
     MaxVar = np.zeros((SweepedParameters,))
     Var = np.zeros((SweepedParameters,))
-
+    print(NumberBest)
+    print(BestFit.shape)
     for i in range(SweepedParameters):
         for j in range(len(BestFit)):
-            AbMatrix[i, j] = SweepMatrix[BestFit[j]+1,i]
+            AbMatrix[i, j] = SweepMatrix[BestFit[j],i]
         MaxVar[i] = np.var(SweepMatrix[:, i])
         Var[i] = np.var(AbMatrix[i, :])/MaxVar[i]
 
@@ -200,6 +201,33 @@ def EvaluateSimulations(MatFolder, MagnetName, MeasFile, SweepObject, Mat = True
 
     #Make fancy plot
     if Plots:
+        ##Plot1
+        fig = plt.figure()
+        ax = fig.add_subplot(111)
+        opacity = 0.5
+        dec = 0.4/NumberBest
+        colors = cm.spring
+        TotLength = int(len(SimData[0,:])/2)
+        LengthStep = int(TotLength/len(BestFit))
+        ax.plot(SimData[0, 1:].astype(float), SimData[BestFit[0]+1, 1:].astype(float), color=colors(2*opacity),
+                alpha=opacity, label='_nolegend_')
+        # ax.text(SimData[0, TotLength].astype(float),SimData[BestFit[0]+1, TotLength].astype(float), str(0), alpha = opacity)
+        for i in range(1,len(BestFit)):
+            opacity = (opacity - dec)
+            ax.plot(SimData[0, 1:].astype(float), SimData[BestFit[i]+1, 1:].astype(float), color=colors(2*opacity),
+                    alpha=opacity, label='_nolegend_')
+            # ax.text(SimData[0, TotLength+i*LengthStep].astype(float), SimData[BestFit[i]+1, TotLength+i*LengthStep].astype(float), str(i),
+            #         alpha=opacity)
+        sm = plt.cm.ScalarMappable(cmap=colors)
+        cbar = plt.colorbar(sm)
+        cbar.set_ticks([1])
+        cbar.set_ticklabels(["Best Fit"])
+        meas = ax.plot(Tmeas2, Imeas2, color='black', label='Measurement')
+        ax.set_xlabel('t [s]', fontsize =20)
+        ax.set_ylabel('I [A]', fontsize =20)
+        ax.legend(fontsize =20)
+        ax.grid(True)
+
         flag_No3Dplots = 0
         try:
             #Plot two most important parameters together on MSE
@@ -254,33 +282,6 @@ def EvaluateSimulations(MatFolder, MagnetName, MeasFile, SweepObject, Mat = True
         except:
             pass
 
-        ##Plot1
-        fig = plt.figure()
-        ax = fig.add_subplot(111)
-        opacity = 0.5
-        dec = 0.4/NumberBest
-        colors = cm.spring
-        TotLength = int(len(SimData[0,:])/2)
-        LengthStep = int(TotLength/len(BestFit))
-        ax.plot(SimData[0, 1:].astype(float), SimData[BestFit[0]+1, 1:].astype(float), color=colors(2*opacity),
-                alpha=opacity, label='_nolegend_')
-        # ax.text(SimData[0, TotLength].astype(float),SimData[BestFit[0]+1, TotLength].astype(float), str(0), alpha = opacity)
-        for i in range(1,len(BestFit)):
-            opacity = (opacity - dec)
-            ax.plot(SimData[0, 1:].astype(float), SimData[BestFit[i]+1, 1:].astype(float), color=colors(2*opacity),
-                    alpha=opacity, label='_nolegend_')
-            # ax.text(SimData[0, TotLength+i*LengthStep].astype(float), SimData[BestFit[i]+1, TotLength+i*LengthStep].astype(float), str(i),
-            #         alpha=opacity)
-        sm = plt.cm.ScalarMappable(cmap=colors)
-        cbar = plt.colorbar(sm)
-        cbar.set_ticks([1])
-        cbar.set_ticklabels(["Best Fit"])
-        meas = ax.plot(Tmeas2, Imeas2, color='black', label='Measurement')
-        ax.set_xlabel('t [s]')
-        ax.set_ylabel('I [A]')
-        ax.legend(fontsize =11)
-        ax.grid(True)
-
         if flag_No3Dplots==1: return
         ##Plot 2
         verts = []
